package com.sun.tools.javap.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "18.0.2.1+1" },
            { "jdk", "18.0.2.1" },
            { "release", "18.0.2.1" },
        };
    }
}
